@@ -198,106 +198,3 @@ def mat_dis(A,B):
     return(np.sum(np.abs(A-B)))
 
 
-##################Currently Not used functions##################
-#@jit(nopython=True,cache=True)
-def _outer_product(B1,B2,norm,conj):
-    '''
-    Input
-    B1 2 x 2 x m x n array
-    B2 2 x 2 x m x n array
-    Output
-    M 4 x 4 x m x n
-    '''
-    
-    #assert B1.shape==B2.shape
-    
-    s = B1.shape
-    
-    M = np.zeros((4,4,s[2],s[3]),dtype=np.complex128)
-    
-    indx_b1 = np.array([[[0,0],[0,0],[0,1],[0,1]],[[0,0],[0,0],[0,1],[0,1]],[[1,0],[1,0],[1,1],[1,1]],[[1,0],[1,0],[1,1],[1,1]]])
-    indx_b2 = np.array([[[0,0],[0,1],[0,0],[0,1]],[[1,0],[1,1],[1,0],[1,1]],[[0,0],[0,1],[0,0],[0,1]],[[1,0],[1,1],[1,0],[1,1]]])
-    #print(indx_b1.shape)
-    
-    
-    for i in range(4):
-        for j in range(4):
-            #print(indx_b1[i,j,:], ',*,', indx_b2[i,j,:])
-            if conj:
-                M[i,j,:,:] = B1[indx_b1[i,j,0],indx_b1[i,j,1],:,:] * B2[indx_b2[i,j,0],indx_b2[i,j,1],:,:].conj().T
-            else:
-                M[i,j,:,:] = B1[indx_b1[i,j,0],indx_b1[i,j,1],:,:] * B2[indx_b2[i,j,0],indx_b2[i,j,1],:,:]
-                
-            if norm:
-                M[i,j,:,:] = M[i,j,:,:]/np.max(np.abs(M[i,j,:,:]))
-    
-    #print(M.shape)
-    return(M)
-
-
-def _outer_product_conv(B1,B2):
-    
-#    Input
-#    B1 2 x 2 x m x n array
-#    B2 2 x 2 x m x n array
-#    Output
-#    M 4 x 4 x m x n
-    
-    #assert B1.shape==B2.shape
-    
-    s = B1.shape
-    
-    M = np.zeros((4,4,s[2],s[3]),dtype=np.complex128)
-    
-    indx_b1 = np.array([[[0,0],[0,0],[0,1],[0,1]],[[0,0],[0,0],[0,1],[0,1]],[[1,0],[1,0],[1,1],[1,1]],[[1,0],[1,0],[1,1],[1,1]]])
-    indx_b2 = np.array([[[0,0],[0,1],[0,0],[0,1]],[[1,0],[1,1],[1,0],[1,1]],[[0,0],[0,1],[0,0],[0,1]],[[1,0],[1,1],[1,0],[1,1]]])
-    
-    for i in range(4):
-        for j in range(4):
-            M[i,j,:,:] = signal.fftconvolve(B1[indx_b1[i,j,0],indx_b1[i,j,1],:,:], B2[indx_b2[i,j,0],indx_b2[i,j,1],:,:],mode='same')
-    
-    print(M.shape)
-    return(M)
-
-    
-def _make_flat(B):
-    '''
-    B 2x2xmxn
-    B_flat 2mx2n
-    '''
-    s = B.shape
-    B_flat = np.zeros((s[2]*s[0],s[3]*s[1]),dtype=complex)
-    
-    
-    for i in range(s[0]):
-        for j in range(s[1]):
-            i_start = i*s[2]
-            i_end = (i+1)*s[3]
-            j_start = j*s[2]
-            j_end = (j+1)*s[3]
-            B_flat[i_start:i_end,j_start:j_end] = B[i,j,:,:]
-            #print(B[i,j,1024,1024],np.abs(B[i,j,1024,1024]))
-    return B_flat
-    
-    
-def _make_flat_casa(B):
-    '''
-    B mxnx16
-    B_flat 4mx4n
-    '''
-    s = B.shape
-    B_flat = np.zeros((s[0]*4,s[1]*4),dtype=complex)
-    
-    #indx = np.array([[0,0],[1,0],[2,0],[3,0],[0,1],[1,1],[2,1],[3,1],[0,2],[1,2],[2,2],[3,2],[0,3],[1,3],[2,3],[3,3]])
-    indx = np.array([[0,0],[0,1],[0,2],[0,3],[1,0],[1,1],[1,2],[1,3],[2,0],[2,1],[2,2],[2,3],[3,0],[3,1],[3,2],[3,3]]) #saved as rows
-    
-    for c,i in enumerate(indx):
-        #print(c,i)
-        i_start = i[0]*s[0]
-        i_end = (i[0]+1)*s[0]
-        j_start = i[1]*s[1]
-        j_end = (i[1]+1)*s[1]
-        B_flat[i_start:i_end,j_start:j_end] = B[:,:,c].T
-        #print(B[1024,1024,c],np.abs(B[1024,1024,c]))
-    return B_flat
-
